summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneylistviewitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneylistviewitem.h')
-rw-r--r--kmymoney2/widgets/kmymoneylistviewitem.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kmymoney2/widgets/kmymoneylistviewitem.h b/kmymoney2/widgets/kmymoneylistviewitem.h
index 64f7562..4009aef 100644
--- a/kmymoney2/widgets/kmymoneylistviewitem.h
+++ b/kmymoney2/widgets/kmymoneylistviewitem.h
@@ -21,7 +21,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qobject.h>
+#include <tqobject.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -34,32 +34,33 @@
class KMyMoneyCheckListItem;
/**
* This class implements a derived version of a QListViewItem that
* allows the storage of an engine object id with the object
*
* @author Thomas Baumgart
*/
-class KMyMoneyListViewItem : public QObject, public KListViewItem
+class KMyMoneyListViewItem : public TQObject, public KListViewItem
{
friend class KMyMoneyCheckListItem;
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyListViewItem(QListView *parent, const QString& txt, const QString& key, const QString& id);
- KMyMoneyListViewItem(QListViewItem *parent, const QString& txt, const QString& key, const QString& id);
+ KMyMoneyListViewItem(TQListView *tqparent, const TQString& txt, const TQString& key, const TQString& id);
+ KMyMoneyListViewItem(TQListViewItem *tqparent, const TQString& txt, const TQString& key, const TQString& id);
~KMyMoneyListViewItem();
- const QString& id(void) const { return m_id; };
+ const TQString& id(void) const { return m_id; };
/**
* use my own paint method
*/
- void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
/**
* use my own backgroundColor method
*/
- const QColor backgroundColor();
+ const TQColor backgroundColor();
/**
* This method returns a const reference to the key passed to the constructor. The column
@@ -67,7 +68,7 @@ public:
* the constructor concatenated with the value returned by text(0) is returned. For @a column
* equals to 1, the @a key as passed to the constructor except the first character is returned.
*/
- QString key(int column, bool ascending) const;
+ TQString key(int column, bool ascending) const;
/**
@@ -76,8 +77,8 @@ public:
bool isAlternate(void);
private:
- QString m_key;
- QString m_id;
+ TQString m_key;
+ TQString m_id;
// copied from KListViewItem()
unsigned int m_isOdd : 1;
unsigned int m_isKnown : 1;
@@ -34,32 +34,33 @@
class KMyMoneyCheckListItem;
/**
- * This class implements a derived version of a QListViewItem that
+ * This class implements a derived version of a TQListViewItem that
* allows the storage of an engine object id with the object
*